@@ -8,7 +8,7 @@ Perl::Dist::WiX::Asset::Launcher - Start menu launcher asset for a Win32 Perl
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Asset::Launcher version 1.250.
+This document describes Perl::Dist::WiX::Asset::Launcher version 1.500.
 
 =head1 SYNOPSIS
 
@@ -36,13 +36,13 @@ perl binary directory.
 
 =cut
 
-use 5.008001;
+use 5.010;
 use Moose;
 use MooseX::Types::Moose qw( Str Bool );
 use File::Spec::Functions qw( catfile );
 use Perl::Dist::WiX::Exceptions;
 
-our $VERSION = '1.250';
+our $VERSION = '1.500';
 $VERSION =~ s/_//ms;
 
 with 'Perl::Dist::WiX::Role::NonURLAsset';
@@ -150,7 +150,7 @@ sub install {
 
 	# Check the script exists
 	my $to = catfile( $self->_get_image_dir(), 'perl', 'bin', "$bin$ext" );
-	unless ( -f $to ) {
+	if ( not -f $to ) {
 		PDWiX::File->throw(
 			file    => $to,
 			message => 'File does not exist'
