@@ -8,7 +8,7 @@ Perl::Dist::WiX::Tag::DirectoryRef - <DirectoryRef> tag that knows how to search
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Tag::DirectoryRef version 1.250.
+This document describes Perl::Dist::WiX::Tag::DirectoryRef version 1.500.
 
 =head1 SYNOPSIS
 
@@ -39,14 +39,14 @@ L<Perl::Dist::WiX|Perl::Dist::WiX>-based distribution.
 
 =cut
 
-use 5.008001;
+use 5.010;
 use Moose;
 use MooseX::Types::Moose qw( Str );
 use File::Spec::Functions qw( catdir abs2rel );
 use Params::Util qw( _STRING _INSTANCE );
 require Perl::Dist::WiX::Tag::Directory;
 
-our $VERSION = '1.250';
+our $VERSION = '1.500';
 $VERSION =~ s/_//ms;
 
 extends 'WiX3::XML::DirectoryRef';
@@ -143,7 +143,7 @@ sub search_dir {
 	# This is hit enough to take up a lot of time when profiling.
 	my $path = $self->{directory_object}->{path};
 
-	return undef unless defined $path;
+	return undef if not defined $path;
 
 	$self->trace_line( 3, "Looking for $path_to_find\n" );
 	$self->trace_line( 4, "  in:      $path.\n" );
@@ -157,7 +157,7 @@ sub search_dir {
 	}
 
 	# Quick exit if required.
-	return undef unless $descend;
+	return undef if not $descend;
 
 	# Do we want to continue searching down this direction?
 	my $subset = "$path_to_find\\" =~ m{\A\Q$path\E\\}msx;
@@ -174,7 +174,7 @@ sub search_dir {
 
   TAG:
 	foreach my $tag (@tags) {
-		next TAG unless $tag->isa('Perl::Dist::WiX::Tag::Directory');
+		next TAG if not $tag->isa('Perl::Dist::WiX::Tag::Directory');
 
 		my $x = ref $tag;
 		my $y = $tag->get_path();
@@ -191,7 +191,8 @@ sub search_dir {
 
 
 
-sub _add_directory_recursive {
+sub _add_directory_recursive
+{ ## no critic(ProhibitUnusedPrivateSubroutines)
 	my $self         = shift;
 	my $path_to_find = shift;
 	my $dir_to_add   = shift;
